using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Runtime.Serialization;
using Newtonsoft.Json;

namespace IO.Swagger.Model {

  /// <summary>
  /// 订单详情
  /// </summary>
  [DataContract]
  public class OrderDetail {
    
    /// <summary>
    /// 订单详细信息。维护订单，数组里只有1个。安装订单，里面可能为0个，也可能为多个。看工作进展情况。
    /// </summary>
    /// <value>订单详细信息。维护订单，数组里只有1个。安装订单，里面可能为0个，也可能为多个。看工作进展情况。</value>
    [DataMember(Name="vehicles", EmitDefaultValue=false)]
    public List<VehicleInOrder> Vehicles { get; set; }

    
    /// <summary>
    /// Gets or Sets WorkAddr
    /// </summary>
    [DataMember(Name="workAddr", EmitDefaultValue=false)]
    public WorkAddr WorkAddr { get; set; }

    
    /// <summary>
    /// 订单号
    /// </summary>
    /// <value>订单号</value>
    [DataMember(Name="id", EmitDefaultValue=false)]
    public string Id { get; set; }

    
    /// <summary>
    /// 客户企业的Id
    /// </summary>
    /// <value>客户企业的Id</value>
    [DataMember(Name="clientCompanyId", EmitDefaultValue=false)]
    public string ClientCompanyId { get; set; }

    
    /// <summary>
    /// 客户公司名
    /// </summary>
    /// <value>客户公司名</value>
    [DataMember(Name="clientCompany", EmitDefaultValue=false)]
    public string ClientCompany { get; set; }

    
    /// <summary>
    /// 联盟成员接单企业的Id
    /// </summary>
    /// <value>联盟成员接单企业的Id</value>
    [DataMember(Name="serviceCompanyId", EmitDefaultValue=false)]
    public string ServiceCompanyId { get; set; }

    
    /// <summary>
    /// 联盟成员公司名
    /// </summary>
    /// <value>联盟成员公司名</value>
    [DataMember(Name="serviceCompany", EmitDefaultValue=false)]
    public string ServiceCompany { get; set; }

    
    /// <summary>
    /// 联盟成员受托公司Id
    /// </summary>
    /// <value>联盟成员受托公司Id</value>
    [DataMember(Name="consigneeCompanyId", EmitDefaultValue=false)]
    public string ConsigneeCompanyId { get; set; }

    
    /// <summary>
    /// 委托公司名
    /// </summary>
    /// <value>委托公司名</value>
    [DataMember(Name="consigneeCompany", EmitDefaultValue=false)]
    public string ConsigneeCompany { get; set; }

    
    /// <summary>
    /// 订单类型(安装，维护，in Excel)
    /// </summary>
    /// <value>订单类型(安装，维护，in Excel)</value>
    [DataMember(Name="type", EmitDefaultValue=false)]
    public int? Type { get; set; }

    
    /// <summary>
    /// 订单价格
    /// </summary>
    /// <value>订单价格</value>
    [DataMember(Name="price", EmitDefaultValue=false)]
    public float? Price { get; set; }

    
    /// <summary>
    /// 委托价格。（如果已经委托。）
    /// </summary>
    /// <value>委托价格。（如果已经委托。）</value>
    [DataMember(Name="consignPrice", EmitDefaultValue=false)]
    public float? ConsignPrice { get; set; }

    
    /// <summary>
    /// 安装数量（如果是安装订单，有效；维护订单无效）
    /// </summary>
    /// <value>安装数量（如果是安装订单，有效；维护订单无效）</value>
    [DataMember(Name="numberToInstall", EmitDefaultValue=false)]
    public int? NumberToInstall { get; set; }

    
    /// <summary>
    /// 故障现象的ID
    /// </summary>
    /// <value>故障现象的ID</value>
    [DataMember(Name="problemId", EmitDefaultValue=false)]
    public int? ProblemId { get; set; }

    
    /// <summary>
    /// 故障现象文字说明
    /// </summary>
    /// <value>故障现象文字说明</value>
    [DataMember(Name="problemDesc", EmitDefaultValue=false)]
    public string ProblemDesc { get; set; }

    
    /// <summary>
    /// 故障分析的ID
    /// </summary>
    /// <value>故障分析的ID</value>
    [DataMember(Name="analysisId", EmitDefaultValue=false)]
    public int? AnalysisId { get; set; }

    
    /// <summary>
    /// 故障分析的文字
    /// </summary>
    /// <value>故障分析的文字</value>
    [DataMember(Name="analysisDesc", EmitDefaultValue=false)]
    public string AnalysisDesc { get; set; }

    
    /// <summary>
    /// 紧急程度
    /// </summary>
    /// <value>紧急程度</value>
    [DataMember(Name="urgency", EmitDefaultValue=false)]
    public int? Urgency { get; set; }

    
    /// <summary>
    /// 订单详情页面的URL。
    /// </summary>
    /// <value>订单详情页面的URL。</value>
    [DataMember(Name="detailUrl", EmitDefaultValue=false)]
    public string DetailUrl { get; set; }

    
    /// <summary>
    /// 订单状态页面的URL。
    /// </summary>
    /// <value>订单状态页面的URL。</value>
    [DataMember(Name="stateSeqUrl", EmitDefaultValue=false)]
    public string StateSeqUrl { get; set; }

    
    /// <summary>
    /// 当前状态
    /// </summary>
    /// <value>当前状态</value>
    [DataMember(Name="currentStateName", EmitDefaultValue=false)]
    public string CurrentStateName { get; set; }

    
    /// <summary>
    /// 当前状态的时间
    /// </summary>
    /// <value>当前状态的时间</value>
    [DataMember(Name="currentStateTime", EmitDefaultValue=false)]
    public string CurrentStateTime { get; set; }

    
    /// <summary>
    /// 公务车列表, K=Id, V=牌照
    /// </summary>
    /// <value>公务车列表, K=Id, V=牌照</value>
    [DataMember(Name="serviceVehicles", EmitDefaultValue=false)]
    public List<StrKVPair> ServiceVehicles { get; set; }

    
    /// <summary>
    /// 可以进行的操作。如果数组中，没有内容，说明该用户没有可执行操作。
    /// </summary>
    /// <value>可以进行的操作。如果数组中，没有内容，说明该用户没有可执行操作。</value>
    [DataMember(Name="actions", EmitDefaultValue=false)]
    public List<Action> Actions { get; set; }

    
    /// <summary>
    /// Gets or Sets Error
    /// </summary>
    [DataMember(Name="error", EmitDefaultValue=false)]
    public ApiError Error { get; set; }

    

    /// <summary>
    /// Get the string presentation of the object
    /// </summary>
    /// <returns>String presentation of the object</returns>
    public override string ToString()  {
      var sb = new StringBuilder();
      sb.Append("class OrderDetail {\n");
      
      sb.Append("  Vehicles: ").Append(Vehicles).Append("\n");
      
      sb.Append("  WorkAddr: ").Append(WorkAddr).Append("\n");
      
      sb.Append("  Id: ").Append(Id).Append("\n");
      
      sb.Append("  ClientCompanyId: ").Append(ClientCompanyId).Append("\n");
      
      sb.Append("  ClientCompany: ").Append(ClientCompany).Append("\n");
      
      sb.Append("  ServiceCompanyId: ").Append(ServiceCompanyId).Append("\n");
      
      sb.Append("  ServiceCompany: ").Append(ServiceCompany).Append("\n");
      
      sb.Append("  ConsigneeCompanyId: ").Append(ConsigneeCompanyId).Append("\n");
      
      sb.Append("  ConsigneeCompany: ").Append(ConsigneeCompany).Append("\n");
      
      sb.Append("  Type: ").Append(Type).Append("\n");
      
      sb.Append("  Price: ").Append(Price).Append("\n");
      
      sb.Append("  ConsignPrice: ").Append(ConsignPrice).Append("\n");
      
      sb.Append("  NumberToInstall: ").Append(NumberToInstall).Append("\n");
      
      sb.Append("  ProblemId: ").Append(ProblemId).Append("\n");
      
      sb.Append("  ProblemDesc: ").Append(ProblemDesc).Append("\n");
      
      sb.Append("  AnalysisId: ").Append(AnalysisId).Append("\n");
      
      sb.Append("  AnalysisDesc: ").Append(AnalysisDesc).Append("\n");
      
      sb.Append("  Urgency: ").Append(Urgency).Append("\n");
      
      sb.Append("  DetailUrl: ").Append(DetailUrl).Append("\n");
      
      sb.Append("  StateSeqUrl: ").Append(StateSeqUrl).Append("\n");
      
      sb.Append("  CurrentStateName: ").Append(CurrentStateName).Append("\n");
      
      sb.Append("  CurrentStateTime: ").Append(CurrentStateTime).Append("\n");
      
      sb.Append("  ServiceVehicles: ").Append(ServiceVehicles).Append("\n");
      
      sb.Append("  Actions: ").Append(Actions).Append("\n");
      
      sb.Append("  Error: ").Append(Error).Append("\n");
      
      sb.Append("}\n");
      return sb.ToString();
    }

    /// <summary>
    /// Get the JSON string presentation of the object
    /// </summary>
    /// <returns>JSON string presentation of the object</returns>
    public string ToJson() {
      return JsonConvert.SerializeObject(this, Formatting.Indented);
    }

}
}
